summaryrefslogtreecommitdiff
path: root/chromium/components/security_interstitials/content/unsafe_resource.cc
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/components/security_interstitials/content/unsafe_resource.cc')
-rw-r--r--chromium/components/security_interstitials/content/unsafe_resource.cc8
1 files changed, 6 insertions, 2 deletions
diff --git a/chromium/components/security_interstitials/content/unsafe_resource.cc b/chromium/components/security_interstitials/content/unsafe_resource.cc
index 6a29eb121e7..f9693b52796 100644
--- a/chromium/components/security_interstitials/content/unsafe_resource.cc
+++ b/chromium/components/security_interstitials/content/unsafe_resource.cc
@@ -47,8 +47,12 @@ bool UnsafeResource::IsMainPageLoadBlocked() const {
case safe_browsing::SB_THREAT_TYPE_URL_CLIENT_SIDE_MALWARE:
// Ad sampling happens in the background.
case safe_browsing::SB_THREAT_TYPE_AD_SAMPLE:
- // Password reuse warning happens after the page is finished loading.
- case safe_browsing::SB_THREAT_TYPE_PASSWORD_REUSE:
+ // Sign-in password reuse warning happens after the page is finished
+ // loading.
+ case safe_browsing::SB_THREAT_TYPE_SIGN_IN_PASSWORD_REUSE:
+ // Enterprise password reuse warning happens after the page is finished
+ // loading.
+ case safe_browsing::SB_THREAT_TYPE_ENTERPRISE_PASSWORD_REUSE:
// Suspicious site collection happens in the background
case safe_browsing::SB_THREAT_TYPE_SUSPICIOUS_SITE:
return false;